#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 vector-sized
version:              1.6.1
visibility:           public
id:                   vector-sized-1.6.1-E0AKXMIWzv8CXxwJZLYikm
key:                  vector-sized-1.6.1-E0AKXMIWzv8CXxwJZLYikm
license:              BSD-3-Clause
copyright:            2016 Ellie Hermaszewska
maintainer:           whats.our.vector.victor@monoid.al
author:               Ellie Hermaszewska
homepage:             https://github.com/expipiplus1/vector-sized#readme
synopsis:             Size tagged vectors
description:          Please see README.md
category:             Data
abi:                  523c68e4ceaea872928837482a306ceb
exposed:              True
exposed-modules:
    Data.Vector.Generic.Mutable.Sized
    Data.Vector.Generic.Mutable.Sized.Internal
    Data.Vector.Generic.Sized Data.Vector.Generic.Sized.Internal
    Data.Vector.Mutable.Sized Data.Vector.Primitive.Mutable.Sized
    Data.Vector.Primitive.Sized Data.Vector.Sized
    Data.Vector.Storable.Mutable.Sized Data.Vector.Storable.Sized
    Data.Vector.Unboxed.Mutable.Sized Data.Vector.Unboxed.Sized

import-dirs:          /usr/lib/ghc-9.6.6/site-local/vector-sized-1.6.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/vector-sized-1.6.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/vector-sized-1.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vector-sized
hs-libraries:         HSvector-sized-1.6.1-E0AKXMIWzv8CXxwJZLYikm
depends:
    adjunctions-4.4.4-6m0UozfZCg78xVBqC0LC7l base-4.18.2.1
    binary-0.8.9.1 comonad-5.0.10-ENOCKhs0LOzIQmGCfXz2st
    deepseq-1.4.8.1 distributive-0.6.3-86aMf1NY2SkAshQXjPjSQp
    finite-typelits-0.2.1.0-3LXTsZ65OsfB43fs5B1oNO
    hashable-1.4.7.0-3I1JJMFn7WVBoCbELVuec1
    indexed-list-literals-0.2.1.3-JnqyU4tFFEs2CSYG8lr4hR
    indexed-traversable-0.1.4-8j5HZpShpE5BqFup9Ojenr
    primitive-0.9.1.0-CEhZf8K56BF7coEYBbWRmS
    vector-0.13.2.0-KEJu75twlkr1fQ5agH441G

haddock-interfaces:
    /usr/share/doc/haskell-vector-sized/html/vector-sized.haddock

haddock-html:         /usr/share/doc/haskell-vector-sized/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

